.. currentmodule:: sardana.sardanaevent

:mod:`~sardana.pool.sardanaevent`
====================================

.. automodule:: sardana.sardanaevent

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`EventGenerator`
    * :class:`EventReceiver`
    * :class:`EventType`


EventGenerator
---------------

.. inheritance-diagram:: EventGenerator
    :parts: 1
    
.. autoclass:: EventGenerator
    :inherited-members:
    :members:
    :undoc-members:
    
EventReceiver
---------------

.. inheritance-diagram:: EventReceiver
    :parts: 1
    
.. autoclass:: EventReceiver
    :inherited-members:
    :members:
    :undoc-members:
    
EventType
---------------

.. inheritance-diagram:: EventType
    :parts: 1
    
.. autoclass:: EventType
    :inherited-members:
    :members:
    :undoc-members:
